Stan Math Library: stan/math/prim/scal/prob/bernoulli_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

bernoulli_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_BERNOULLI_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_BERNOULLI_RNG_HPP
3
4 #include <boost/random/bernoulli_distribution.hpp>
5 #include <boost/random/variate_generator.hpp>
6 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
7 #include <stan/math/prim/scal/err/check_bounded.hpp>
8 #include <stan/math/prim/scal/err/check_finite.hpp>
9 #include <stan/math/prim/scal/err/check_not_nan.hpp>
10 #include <stan/math/prim/scal/fun/constants.hpp>
11 #include <stan/math/prim/scal/fun/inv_logit.hpp>
12 #include <stan/math/prim/scal/fun/log1m.hpp>
13 #include <stan/math/prim/scal/fun/value_of.hpp>
14 #include <stan/math/prim/scal/meta/include_summand.hpp>
15
16 namespace stan {
17
18 namespace math {
19
20 template <class RNG>
21 inline int
22 bernoulli_rng(const double theta,
23 RNG& rng) {
24 using boost::variate_generator;
25 using boost::bernoulli_distribution;
26
27 static const char* function("stan::math::bernoulli_rng");
28
29 using stan::math::check_finite;
30 using stan::math::check_bounded;
31
32 check_finite(function, "Probability parameter", theta);
33 check_bounded(function, "Probability parameter", theta, 0, 1);
34
35 variate_generator<RNG&, bernoulli_distribution<> >
36 bernoulli_rng(rng, bernoulli_distribution<>(theta));
37 return bernoulli_rng();
38 }
39 }
40 }
41 #endif
check_not_nan.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::check_bounded
bool check_bounded(const char *function, const char *name, const T_y &y, const T_low &low, const T_high &high)
Return true if the value is between the low and high values, inclusively.
Definition: check_bounded.hpp:95
stan::math::bernoulli_rng
int bernoulli_rng(const double theta, RNG &rng)
Definition: bernoulli_rng.hpp:22
include_summand.hpp
log1m.hpp
check_bounded.hpp
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
value_of.hpp
inv_logit.hpp
check_consistent_sizes.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.